field_label — Camelot documentation

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »
- controls »

# field_label

class `camelot.view.controls.field_label.` `Attribute`(name, value)

  Helper class representing a field attribute’s name and its value

class `camelot.view.controls.field_label.` `FieldLabel`(field_name, text, field_attributes, admin, parent=None)

  A Label widget used to display the name of a field on a form. This label provides the user with the possibility to change the translation of the label and review its field attributes.

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »
- controls »

Comments
blog comments powered by Disqus